@@ -8,6 +8,8 @@ from pyorbit.common.common_jitter import CommonJitter
 
 from pyorbit.common.harmonics import CommonHarmonics
 
+from pyorbit.common.sinusoid import CommonSinusoid
+
 from pyorbit.common.dilution_factor import CommonDilutionFactor
 from pyorbit.common.normalization_factor import CommonNormalizationFactor
 from pyorbit.common.star_parameters import CommonStarParameters
@@ -35,6 +37,10 @@ from pyorbit.models.pytransit_transit_with_ttv import PyTransit_Transit_With_TTV
 from pyorbit.models.batman_transit import Batman_Transit
 from pyorbit.models.batman_transit_with_ttv import Batman_Transit_With_TTV
 from pyorbit.models.batman_transit_ttv_subset import Batman_Transit_TTV_Subset
+from pyorbit.models.batman_transit_ttv_subset_faster import Batman_Transit_TTV_Subset_Faster
+
+from pyorbit.models.batman_transit_rprs_subset import Batman_Transit_RpRs_Subset
+
 from pyorbit.models.batman_transit_secondary_phasecurve import Batman_Transit_Eclipse_PhaseCurve
 from pyorbit.models.spiderman_thermal import Spiderman_Thermal
 
@@ -71,7 +77,7 @@ from pyorbit.models.correlation import LocalCorrelation
 from pyorbit.models.correlated_jitter import LocalCorrelatedJitter
 from pyorbit.models.common_offset import Offset
 from pyorbit.models.common_jitter import Jitter
-from pyorbit.models.sinusoid_common_period import SinusoidCommonPeriod
+from pyorbit.models.sinusoid import Sinusoid, LocalSinusoid, SinusoidCommonPeriod, SinusoidPolynomialModulation
 from pyorbit.models.harmonics import Harmonics
 
 from pyorbit.models.dilution_factor import DilutionFactor, LocalDilutionFactor
@@ -79,7 +85,7 @@ from pyorbit.models.normalization_factor import NormalizationFactor, LocalNormal
 
 from pyorbit.models.rossitermclaughlin_ohta import RossiterMcLaughling_Ohta
 
-from pyorbit.models.polynomial_trend import PolynomialTrend, LocalPolynomialTrend, SubsetPolynomialTrend
+from pyorbit.models.polynomial_trend import PolynomialTrend, SharedPolynomialTrend, LocalPolynomialTrend, SubsetPolynomialTrend
 
 from pyorbit.models.spectral_rotation import SpectralRotation, SubsetSpectralRotation, SubsetSpectralRotationPolynomial
 
@@ -101,13 +107,16 @@ from pyorbit.models.tinygp_multidimensional_quasiperiodic_activity import TinyGP
 """
 
 model_requires_planets = ['radial_velocities', 'rv_planets',
-                           'batman_transit', 'pytransit_transit',
-                           'batman_transit_with_ttv', 'pytransit_transit_with_ttv',
-                           'subset_batman_transit_ttv', 'batman_transit_ttv_subset',
-                          'rossitermclaughlin_ohta',
-                          'spiderman_thermal', 'batman_transit_eclipse_phasecurve']
+                          'batman_transit', 'pytransit_transit',
+                          'batman_transit_with_ttv', 'pytransit_transit_with_ttv',
+                          'subset_batman_transit_ttv', 'batman_transit_ttv_subset',
+                          'subset_batman_transit_faster_ttv', 'batman_transit_ttv_subset_faster',
+                         'rossitermclaughlin_ohta',
+                         'spiderman_thermal', 'batman_transit_eclipse_phasecurve']
+
 single_planet_model = ['Tc_planets', 'transit_times']
 transit_time_model = ['Tc_planets', 'transit_times']
+
 model_requires_limbdarkening = ['transit',
                                 'transit_eclipse_phasecurve',
                                 'spectral_rotation',
@@ -120,6 +129,7 @@ define_common_type_to_class = {
     'polynomial_trend': CommonPolynomialTrend,
     'common_offset': CommonOffset,
     'common_jitter': CommonJitter,
+    'sinusoid': CommonSinusoid,
     'harmonics': CommonHarmonics,
     'ld_linear': LimbDarkening_Linear,
     'ld_quadratic': LimbDarkening_Quadratic,
@@ -154,7 +164,11 @@ define_type_to_class = {
     'batman_transit': Batman_Transit,
     'batman_transit_ttv_subset': Batman_Transit_TTV_Subset,
     'subset_batman_transit_ttv': Batman_Transit_TTV_Subset,
+    'batman_transit_ttv_subset_faster': Batman_Transit_TTV_Subset_Faster,
+    'subset_batman_transit_faster_ttv': Batman_Transit_TTV_Subset_Faster,
     'batman_transit_with_ttv': Batman_Transit_With_TTV,
+    'batman_transit_rprs_subset': Batman_Transit_RpRs_Subset,
+    'subset_batman_transit_rprs': Batman_Transit_RpRs_Subset,
     'batman_transit_eclipse_phasecurve': Batman_Transit_Eclipse_PhaseCurve,
     'spiderman_thermal': Spiderman_Thermal,
     'gp_framework_quasiperiodic': GP_Framework_QuasiPeriodicActivity,
@@ -175,13 +189,17 @@ define_type_to_class = {
     'local_correlation': LocalCorrelation,
     'correlation': LocalCorrelation,
     'polynomial_trend': PolynomialTrend,
+    'shared_polynomial_trend': SharedPolynomialTrend,
     'local_polynomial_trend': LocalPolynomialTrend,
     'subset_polynomial_trend': SubsetPolynomialTrend,
     'polynomial_trend_subset': SubsetPolynomialTrend,
     'common_offset': Offset,
     'common_jitter': Jitter,
     'harmonics': Harmonics,
+    'sinusoid': Sinusoid,
+    'local_sinusoid': LocalSinusoid,
     'sinusoid_common_period': SinusoidCommonPeriod,
+    'sinusoid_polynomial_modulation': SinusoidPolynomialModulation,
     'dilution_factor': DilutionFactor,
     'local_dilution_factor': LocalDilutionFactor,
     'normalization_factor': NormalizationFactor,
@@ -222,4 +240,4 @@ datatype_definition = {
               'log(R)', 'log(Rhk)', 'log(RHK)', 'log(R_hk)', 'log(R_HK)'],
     'S_index': ['S', 'S_index', 'Shk', 'SHK', 'S_HK', 'S_hk'],
     'CCF': ['CCF', 'CCFs', 'ccf', 'ccfs']
-}
\ No newline at end of file
+}
