@@ -62,6 +62,10 @@ class Batman_Transit_Eclipse_PhaseCurve(AbstractModel, AbstractTransit):
         except:
             self.code_options['nthreads'] = 1
 
+        if not batman.openmp.detect():
+            print('OpenMP not supported, batman nthreads automatically lowered to 1')
+            self.code_options['nthreads'] = 1
+
         self.batman_params = batman.TransitParams()
 
         if kwargs.get('nightside_emission', True):
