@@ -49,7 +49,7 @@ class GaussianProcess_QuasiPeriodicActivity_Common(AbstractModel):
 
         self.gp = {}
         self.internal_dataset = {'x0': [], 'yr': [], 'ej': []}
-        self.internal_variable_value = None
+        self.internal_parameter_values = None
         self.internal_gp_pams = None
         self.use_HODLR = False
 
@@ -145,13 +145,13 @@ class GaussianProcess_QuasiPeriodicActivity_Common(AbstractModel):
 
         return
 
-    def add_internal_dataset(self, variable_value, dataset, reset_status):
+    def add_internal_dataset(self, parameter_values, dataset, reset_status):
         if not reset_status:
             self.internal_dataset['x0'] = []
             self.internal_dataset['yr'] = []
             self.internal_dataset['ej'] = []
-            self.internal_variable_value = variable_value
-            self.internal_gp_pams = self.convert_val2gp(variable_value)
+            self.internal_parameter_values = parameter_values
+            self.internal_gp_pams = self.convert_val2gp(parameter_values)
 
         self.internal_dataset['x0'].extend(dataset.x0)
         self.internal_dataset['yr'].extend(dataset.residuals)
@@ -163,9 +163,9 @@ class GaussianProcess_QuasiPeriodicActivity_Common(AbstractModel):
            1) theta parameters must be converted in physical units (e.g. from logarithmic to linear spaces)
            2) physical values must be converted to {\tt george} input parameters
         """
-        if not self.hyper_condition(self.internal_variable_value):
+        if not self.hyper_condition(self.internal_parameter_values):
             return -np.inf
-        if not self.rotdec_condition(self.internal_variable_value):
+        if not self.rotdec_condition(self.internal_parameter_values):
             return -np.inf
 
         self.gp.set_parameter_vector(self.internal_gp_pams)
@@ -196,17 +196,18 @@ class GaussianProcess_QuasiPeriodicActivity_Common(AbstractModel):
             return self.gp.sample_conditional(self.internal_dataset['yr'], x0_input)
 
     @staticmethod
-    def _hypercond_00(variable_value):
+    def _hypercond_00(parameter_values):
         #Condition from Rajpaul 2017, Rajpaul+2021
         return True
 
     @staticmethod
-    def _hypercond_01(variable_value):
+    def _hypercond_01(parameter_values):
         # Condition from Rajpaul 2017, Rajpaul+2021
         # Taking into account that Pdec^2 = 2*lambda_2^2
-        return variable_value['Pdec']**2 > (3. / 4. / np.pi) * variable_value['Oamp']**2 * variable_value['Prot']**2 
+        return parameter_values['Pdec']**2 > (3. / 4. / np.pi) * parameter_values['Oamp']**2 * parameter_values['Prot']**2 
 
     @staticmethod
-    def _hypercond_02(variable_value):
+    def _hypercond_02(parameter_values):
         #Condition on Rotation period and decay timescale
-        return variable_value['Pdec'] > 2. * variable_value['Prot']
+        return parameter_values['Pdec'] > 2. * parameter_values['Prot']
+
