@@ -41,7 +41,7 @@ def pyorbit_polychord(config_in, input_datasets=None, return_output=None):
 
     mc.starting_points_setup()
 
-    results_analysis.results_resumen(mc, None, skip_theta=True)
+    results_analysis.results_summary(mc, None, skip_theta=True)
 
     mc.output_directory = output_directory
 
